@@ -39,7 +39,7 @@ logging.getLogger("requests").setLevel(logging.WARNING)
 logging.getLogger("urllib3").setLevel(logging.WARNING)
 
 
-def run_linting(pipeline_dir, release_mode=False, md_fn=None, json_fn=None):
+def run_linting(pipeline_dir, release_mode=False, show_passed=False, md_fn=None, json_fn=None):
     """Runs all nf-core linting checks on a given Nextflow pipeline project
     in either `release` mode or `normal` mode (default). Returns an object
     of type :class:`PipelineLint` after finished.
@@ -65,7 +65,7 @@ def run_linting(pipeline_dir, release_mode=False, md_fn=None, json_fn=None):
         return lint_obj
 
     # Print the results
-    lint_obj.print_results()
+    lint_obj.print_results(show_passed)
 
     # Save results to Markdown file
     if md_fn is not None:
@@ -238,6 +238,7 @@ class PipelineLint(object):
             )
             for fun_name in check_functions:
                 progress.update(lint_progress, advance=1, func_name=fun_name)
+                log.debug("Running lint test: {}".format(fun_name))
                 getattr(self, fun_name)()
                 if len(self.failed) > 0:
                     log.error("Found test failures in `{}`, halting lint run.".format(fun_name))
@@ -770,7 +771,7 @@ class PipelineLint(object):
                 self.passed.append((5, "Continuous integration runs Markdown lint Tests: `{}`".format(fn)))
 
             # Check that the nf-core linting runs
-            nfcore_lint_cmd = "nf-core lint ${GITHUB_WORKSPACE}"
+            nfcore_lint_cmd = "nf-core -l lint_log.txt lint ${GITHUB_WORKSPACE}"
             try:
                 steps = lintwf["jobs"]["nf-core"]["steps"]
                 assert any([nfcore_lint_cmd in step["run"] for step in steps if "run" in step.keys()])
@@ -1225,8 +1226,7 @@ class PipelineLint(object):
         """ Lint the pipeline schema """
 
         # Only show error messages from schema
-        if log.getEffectiveLevel() == logging.INFO:
-            logging.getLogger("nf_core.schema").setLevel(logging.ERROR)
+        logging.getLogger("nf_core.schema").setLevel(logging.ERROR)
 
         # Lint the schema
         self.schema_obj = nf_core.schema.PipelineSchema()
@@ -1273,7 +1273,9 @@ class PipelineLint(object):
         if len(removed_params) == 0 and len(added_params) == 0:
             self.passed.append((15, "Schema matched params returned from nextflow config"))
 
-    def print_results(self):
+    def print_results(self, show_passed=False):
+
+        log.debug("Printing final results")
         console = Console()
 
         # Helper function to format test links nicely
@@ -1294,7 +1296,7 @@ class PipelineLint(object):
             return ""
 
         # Table of passed tests
-        if len(self.passed) > 0 and log.getEffectiveLevel() == logging.DEBUG:
+        if len(self.passed) > 0 and show_passed:
             table = Table(style="green", box=rich.box.ROUNDED)
             table.add_column(
                 "[[\u2714]] {} Test{} Passed".format(len(self.passed), _s(self.passed)), no_wrap=True,
@@ -1438,39 +1440,55 @@ class PipelineLint(object):
         """
         If we are running in a GitHub PR, try to post results as a comment
         """
-        if os.environ.get("GITHUB_TOKEN", "") != "" and os.environ.get("GITHUB_COMMENTS_URL", "") != "":
-            try:
-                headers = {"Authorization": "token {}".format(os.environ["GITHUB_TOKEN"])}
-                # Get existing comments - GET
-                get_r = requests.get(url=os.environ["GITHUB_COMMENTS_URL"], headers=headers)
-                if get_r.status_code == 200:
+        if os.environ.get("GITHUB_TOKEN", "") == "":
+            log.debug("Environment variable GITHUB_TOKEN not found")
+            return
+        if os.environ.get("GITHUB_COMMENTS_URL", "") == "":
+            log.debug("Environment variable GITHUB_COMMENTS_URL not found")
+            return
+        try:
+            headers = {"Authorization": "token {}".format(os.environ["GITHUB_TOKEN"])}
+            # Get existing comments - GET
+            get_r = requests.get(url=os.environ["GITHUB_COMMENTS_URL"], headers=headers)
+            if get_r.status_code == 200:
 
-                    # Look for an existing comment to update
-                    update_url = False
-                    for comment in get_r.json():
-                        if comment["user"]["login"] == "github-actions[bot]" and comment["body"].startswith(
-                            "\n#### `nf-core lint` overall result"
-                        ):
-                            # Update existing comment - PATCH
-                            log.info("Updating GitHub comment")
-                            update_r = requests.patch(
-                                url=comment["url"],
-                                data=json.dumps({"body": self.get_results_md().replace("Posted", "**Updated**")}),
-                                headers=headers,
-                            )
-                            return
-
-                    # Create new comment - POST
-                    if len(self.warned) > 0 or len(self.failed) > 0:
-                        log.info("Posting GitHub comment")
-                        post_r = requests.post(
-                            url=os.environ["GITHUB_COMMENTS_URL"],
-                            data=json.dumps({"body": self.get_results_md()}),
+                # Look for an existing comment to update
+                update_url = False
+                for comment in get_r.json():
+                    if comment["user"]["login"] == "github-actions[bot]" and comment["body"].startswith(
+                        "\n#### `nf-core lint` overall result"
+                    ):
+                        # Update existing comment - PATCH
+                        log.info("Updating GitHub comment")
+                        update_r = requests.patch(
+                            url=comment["url"],
+                            data=json.dumps({"body": self.get_results_md().replace("Posted", "**Updated**")}),
                             headers=headers,
                         )
+                        return
 
-            except Exception as e:
-                log.warning("Could not post GitHub comment: {}\n{}".format(os.environ["GITHUB_COMMENTS_URL"], e))
+                # Create new comment - POST
+                if len(self.warned) > 0 or len(self.failed) > 0:
+                    r = requests.post(
+                        url=os.environ["GITHUB_COMMENTS_URL"],
+                        data=json.dumps({"body": self.get_results_md()}),
+                        headers=headers,
+                    )
+                    try:
+                        r_json = json.loads(r.content)
+                        response_pp = json.dumps(r_json, indent=4)
+                    except:
+                        r_json = r.content
+                        response_pp = r.content
+
+                    if r.status_code == 201:
+                        log.info("Posted GitHub comment: {}".format(r_json["html_url"]))
+                        log.debug(response_pp)
+                    else:
+                        log.warn("Could not post GitHub comment: '{}'\n{}".format(r.status_code, response_pp))
+
+        except Exception as e:
+            log.warning("Could not post GitHub comment: {}\n{}".format(os.environ["GITHUB_COMMENTS_URL"], e))
 
     def _wrap_quotes(self, files):
         if not isinstance(files, list):
